/*
 * field_model.h - functions to predict the earth's geomagnetic field
 *
 * Copyright (C) 1998, John C. Peterson <mailto:jaypee@netcom.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License,
 * version 2. A copy is included in this distribution in the file
 * named "LICENSE".
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License, version 2, for more details.
 *
 * $Id: field_model.h,v 1.1 1998/05/05 05:58:54 jcp Exp $
 *
 */

/* data structures */

typedef struct {
  double latitude;	/* WGS-84 latitude (decimal degrees), N > 0, S < 0 */
  double longitude;	/* WGS-84 longitude (decimal degrees), E > 0, W < 0 */
  double altitude;	/* WGS-84 altitude (kilometers) */
  double date;		/* decimal gregorian year (ie: 1997.491) */
  double dec;		/* declination angle (degrees decimal), E > 0 */
  double dip;		/* inclination angle (degrees decimal), down > 0 */
  double intensity;	/* total field intensity (nanoTesla) */
} field_model_t;

/* function prototypes */

extern char *strerror_field_model(void);
extern int init_field_model(char *filename);
extern int field_model(field_model_t *value);
